Plugins
=======

Plugins allow for modelling of different hydrogen production pathways. They process information and feed it back into the discounted cashflow calculation to model different behaviour (e.g. energy generation, storage, conversion, cost processing etc.)

.. toctree::
   :maxdepth: 1
   :caption: Plugins

   Plugin_Guide
   Capital_Cost_Plugin
   Catalyst_Separation_Plugin
   Fixed_Operating_Cost_Plugin
   Hourly_Irradiation_Plugin
   Multiple_Modules_Plugin
   PEC_Plugin
   Photocatalytic_Plugin
   Photovoltaic_Plugin
   Production_Scaling_Plugin
   Replacement_Plugin
   Solar_Concentrator_Plugin
   Solar_Thermal_Plugin
   Variable_Operating_Cost_Plugin

